==> nextcloud-21.0.4.tgz: nextcloud/apps/accessibility/l10n/nb.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Mørkt tema",
    "Enable dark theme" : "Aktiver mørkt tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Et mørkt tema for å lette på øynene ved å redusere lysstyrken. Den er fortsatt under utvikling, vennligst rapporter feilene som du finner.",
    "High contrast mode" : "Høykontrast-modus",
    "Enable high contrast mode" : "Aktiver høy kontrast",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "En høykontrast modus for å få en lettere navigasjon. Den visuelle kvaliteten vil bli reusert men klarheten vil bli økt.",
    "Dyslexia font" : "Dysleksi skrifttype",
    "Enable dyslexia font" : "Aktiver dysleksi skrifttype",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic er en gratis skrifttype egnet for å minske de mest vanligste lesefeilene som dysleksi forårsaker.",
    "Accessibility" : "Tilgjengelighet",
    "Accessibility options for nextcloud" : "Tilgjengelighetsvalg for nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Gir muligheten for flere tilgjengelighetsvalg for å gjøre det lettere å bruke Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universell utforming er viktig for oss. Vi følger web-standarder og tester for full funksjonalitet, både uten mus og med hjelpeprogrammer, slik som skjermlesere. Vi etterstreber å følge {guidelines}Retningslinjer for tilgjengelighet på nettsider{linkend} 2.1 på nivå AA, og med temaet for høy kontrast også nivå AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ikke nøl med å rapportere problemer på {issuetracker}vår problemdatabase{linkend}. Og bli gjerne med i {designteam}vårt designteam{linkend} hvis du vil bidra."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/accessibility/l10n/nb.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Mørkt tema",
    "Enable dark theme" : "Aktiver mørkt tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Et mørkt tema for å lette på øynene ved å redusere lysstyrken. Den er fortsatt under utvikling, vennligst rapporter feilene som du finner.",
    "High contrast mode" : "Høykontrastmodus",
    "Enable high contrast mode" : "Aktiver høy kontrast",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "En høykontrast modus for å få en lettere navigasjon. Den visuelle kvaliteten vil bli reusert men klarheten vil bli økt.",
    "Dyslexia font" : "Dysleksi skrifttype",
    "Enable dyslexia font" : "Aktiver dysleksi skrifttype",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic er en gratis skrifttype egnet for å minske de mest vanligste lesefeilene som dysleksi forårsaker.",
    "Accessibility" : "Tilgjengelighet",
    "Accessibility options for nextcloud" : "Tilgjengelighetsvalg for nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Gir muligheten for flere tilgjengelighetsvalg for å gjøre det lettere å bruke Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universell utforming er viktig for oss. Vi følger web-standarder og tester for full funksjonalitet, både uten mus og med hjelpeprogrammer, slik som skjermlesere. Vi etterstreber å følge {guidelines}Retningslinjer for tilgjengelighet på nettsider{linkend} 2.1 på nivå AA, og med temaet for høy kontrast også nivå AAA.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ikke nøl med å rapportere problemer på {issuetracker}vår problemdatabase{linkend}. Og bli gjerne med i {designteam}vårt designteam{linkend} hvis du vil bidra."
},
"nplurals=2; plural=(n != 1);");
